@@ -112,6 +112,7 @@ and interesting links:
 import pkg_resources
 
 from ndd import package_setup
+from ndd.counts import CountsDistribution
 from ndd.divergence import DivergenceEstimator
 from ndd.divergence import estimators as divergence_estimators
 from ndd.estimators import EntropyEstimator
@@ -121,17 +122,10 @@ from ndd.nsb import (coinformation, conditional_entropy, from_data, histogram,
                      interaction_information, jensen_shannon_divergence,
                      kullback_leibler_divergence, mutual_information)
 
-package_name = package_setup.package_name
-package_path = package_setup.package_path
-__version__ = pkg_resources.require(package_name)[0].version
+from .package import __title__, __version__
+
 __all__ = [
-    'entropy',
-    'jensen_shannon_divergence',
-    'kullback_leibler_divergence',
-    'interaction_information',
-    'coinformation',
-    'mutual_information',
-    'conditional_entropy',
-    'histogram',
-    'from_data',
+    'coinformation', 'conditional_entropy', 'entropy', 'from_data',
+    'histogram', 'interaction_information', 'jensen_shannon_divergence',
+    'kullback_leibler_divergence', 'mutual_information', 'CountsDistribution'
 ]
